scoretools.GrandStaff
=====================

.. inheritance-diagram:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff
   :private-bases:

.. autoclass:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.engraver_consists

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.engraver_removals

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_semantic

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.preprolated_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.context_name

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_nonsemantic

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.name

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__add__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__repr__

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__str__

   .. note:: Inherited from `__builtin__.object`
